@@ -23,6 +23,37 @@ import pyspatiotemporalgeom.utilities.segLibrary as segLibrary
 import pyspatiotemporalgeom.utilities.hsegLibrary as hsegLibrary
 import struct
 
+
+def pointInPolygon(x, y, poly):
+  ''' 
+  Point in polygon test.  Works for complex regions (multiple faces, holes, faces in holes, etc.)
+
+
+  **Input:**
+
+  + x: the X value of the point to be tested
+  + y: the Y valu of the point to be tested
+  + poly: a list of 2D segments in the usual format: :math:`((x1,y1),(x2,y2))`
+
+  **Output:**
+
+  + boolean value.  `True` if the point is **in** the polygon **OR** if the point is **on** the boundary.  `False` otherwise
+
+  Note, this may be sensitive to floating poitn rounding errors, might need to allow some tolerance in the left hand turn test.
+  '''
+  results = []
+  inside = 0
+  for s in poly:
+          
+          if s[0][1] == s[1][1]:
+                  continue
+          if s[1] < s[0]:
+                  s = (s[1], s[0])
+          if s[0][0] <= x and s[1][0] > x and segLibrary.isLeftTurn(s[0], s[1], (x,y))  <= 0:
+                  inside += 1
+  return inside % 2 != 0
+
+
 def getRandomIntegerRegion( numRandomSegsToGenerate = 50, percentOfSegsToRemove = .05 ):
         '''
 
