@@ -268,11 +268,16 @@ def verticalSegment3DAndSegment3DIntersection( verticalSegProjectedTo2D, seg3D )
     # tougher case, the seg is not in the Z plane
     zvalbig = stem1[1][2]
     zvalsmall = stem1[0][2]
+    zval = ((zvalbig-zvalsmall)*multiplier)+zvalsmall
     if zvalbig < zvalsmall:
         tmp = zvalbig
         zvalbig=zvalsmall
         zvalsmall = tmp
-    zval = ((zvalbig-zvalsmall)*multiplier)+zvalsmall
+        zval = zvalbig - ((zvalbig-zvalsmall)*multiplier)
+    # zval indicates the Z value assuming that the seg starts from zSmall.  If in fact, 
+    # we reversed the seg end points above, we actuallly need to compute the Z val from larger Z value
+    # in that case, zval = zvalbig - ((zvalbig-zvalsmall)*multiplier)
+    
     # now we have the result point on the stem1 seg.  need to do stem2 seg
     result |= set( [(rayp[0],rayp[1],zval)] )
     return list( result )
